using Unity.Burst;
using Unity.Collections;
using Unity.Entities;
using Unity.NetCode;
using UnityEngine;

[WorldSystemFilter(WorldSystemFilterFlags.ClientSimulation | WorldSystemFilterFlags.ThinClientSimulation)]
partial struct GoInGameClientSystem : ISystem {

    [BurstCompile]
    public void OnCreate(ref SystemState state) {
        EntityQueryBuilder entityQueryBuilder = new EntityQueryBuilder(Allocator.Temp).
            WithAll<NetworkId>().WithNone<NetworkStreamInGame>();
        state.RequireForUpdate(state.GetEntityQuery(entityQueryBuilder));
        entityQueryBuilder.Dispose();
    }

    [BurstCompile]
    public void OnUpdate(ref SystemState state) {
        EntityCommandBuffer entityCommandBuffer = new EntityCommandBuffer(Unity.Collections.Allocator.Temp);
        foreach ((
            RefRO<NetworkId> networkId,
            Entity entity)
            in SystemAPI.Query<
                RefRO<NetworkId>>().WithNone<NetworkStreamInGame>().WithEntityAccess()) {

            entityCommandBuffer.AddComponent<NetworkStreamInGame>(entity);
            Debug.Log("Connected! " + entity + " :: " + networkId.ValueRO.Value);

            Entity rpcEntity = entityCommandBuffer.CreateEntity();
            entityCommandBuffer.AddComponent<GoInGameRequestRpc>(rpcEntity);
            entityCommandBuffer.AddComponent<SendRpcCommandRequest>(rpcEntity);
        }
        entityCommandBuffer.Playback(state.EntityManager);
    }

}